from setuptools import setup

setup(
    name='mplgbw',
    version='0.1',
    packages=['mplgbw',],
    license='FreeBSD',
    url='https://bitbucket.org/ahojukka5/mplgbw',
    author='Jukka Aho',
    author_email='ahojukka5@gmail.com',
    long_description=open('README.txt').read(),
)
